package org.dromara.ygpassport.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import cn.hutool.json.JSONObject;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.utils.DateUtils;
import org.dromara.common.web.core.BaseController;
import org.dromara.ygpassport.domain.bo.BugBo;
import org.dromara.ygpassport.domain.dto.WxBugDto;
import org.dromara.ygpassport.domain.vo.BugVo;
import org.dromara.ygpassport.service.IBugService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * 移动端-bug记录
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/ygpassport/wxBug")
public class WxBugController extends BaseController {
    private final IBugService bugService;

    /**
     * 查询问题列表
     *
     * @param jsonObject json中包含一个参数：bug_commiter（学号）
     *
     * @return R<List<WxBugDto>>
     */
    @SaIgnore
    @PostMapping("/list")
    public R<List<WxBugDto>> list(@RequestBody JSONObject jsonObject) {
        String bugCommiter = jsonObject.getStr("bug_commiter");

        List<BugVo> bugVoList = bugService.queryByBugCommiter(bugCommiter);

        List<WxBugDto> wxBugDtoList = new ArrayList<>();

        for (BugVo bugVo : bugVoList) {
            WxBugDto wxBugDto = new WxBugDto(bugVo);
            wxBugDtoList.add(wxBugDto);
        }

        return R.ok(wxBugDtoList);
    }

    /**
     * 添加问题记录
     *
     * @param jsonObject json中包含一个参数：bugBo（问题记录bo）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/add")
    public R<Void> add(@RequestBody JSONObject jsonObject){
        BugBo bo = jsonObject.get("bugBo", BugBo.class);
        bo.setCreateTime(DateUtils.getNowDate());
        return toAjax(bugService.insertByBo(bo));
    }

    /**
     * 修改问题记录
     *
     * @param jsonObject json中包含一个参数：bugBo（问题记录bo）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/edit")
    public R<Void> edit(@RequestBody JSONObject jsonObject){
        BugBo bo = jsonObject.get("bugBo", BugBo.class);

        return toAjax(bugService.updateByBo(bo));
    }

    /**
     * 删除问题记录
     *
     * @param jsonObject json中包含一个参数：ids（需要删除的id数组）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/remove")
    public R<Void> remove(@RequestBody JSONObject jsonObject){
        Long[] ids = jsonObject.get("ids", Long[].class);
        return toAjax(bugService.deleteWithValidByIds(List.of(ids), true));
    }
}
