package org.dromara.ygpassport.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import cn.hutool.json.JSONObject;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.utils.DateUtils;
import org.dromara.common.web.core.BaseController;
import org.dromara.ygpassport.domain.bo.CareerPlansBo;
import org.dromara.ygpassport.domain.dto.WxCareerPlansDto;
import org.dromara.ygpassport.domain.vo.CareerPlansVo;
import org.dromara.ygpassport.service.ICareerPlansService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * 移动端-职业规划-生涯测试报告
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/ygpassport/WxCareerPlans")
public class WxCareerPlansController extends BaseController {

    private final ICareerPlansService careerPlansService;

    /**
     * 查询生涯测试报告列表
     *
     * @param jsonObject json中包含一个参数：stuNo（学号）
     *
     * @return R<List<WxCareerPlansDto>>
     */
    @SaIgnore
    @PostMapping("/list")
    public R<List<WxCareerPlansDto>> list(@RequestBody JSONObject jsonObject) {
        String stuNo = jsonObject.getStr("stuNo");

        List<CareerPlansVo> careerPlansVoList = careerPlansService.queryListByStuNo(stuNo);

        List<WxCareerPlansDto> wxCareerPlansDtoList = new ArrayList<>();

        for (CareerPlansVo careerPlansVo : careerPlansVoList) {
            WxCareerPlansDto wxCareerPlansDto = new WxCareerPlansDto(careerPlansVo);
            wxCareerPlansDtoList.add(wxCareerPlansDto);
        }

        return R.ok(wxCareerPlansDtoList);
    }

    /**
     * 新增生涯测试报告
     *
     * @param jsonObject json中包含一个参数：careerPlansBo（生涯测试报告bo）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/add")
    public R<Void> add(@RequestBody JSONObject jsonObject){
        CareerPlansBo bo = jsonObject.get("careerPlansBo", CareerPlansBo.class);
        bo.setCreateTime(DateUtils.getNowDate());
        return toAjax(careerPlansService.insertByBo(bo));
    }

    /**
     * 删除生涯测试报告
     *
     * @param jsonObject json中包含一个参数：ids（需要删除的id数组）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/remove")
    public R<Void> remove(@RequestBody JSONObject jsonObject){
        Long[] ids = jsonObject.get("ids", Long[].class);
        return toAjax(careerPlansService.deleteWithValidByIds(List.of(ids), true));
    }

}
