package org.dromara.ygpassport.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import cn.hutool.json.JSONObject;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.utils.DateUtils;
import org.dromara.common.web.core.BaseController;
import org.dromara.ygpassport.domain.bo.ResearchBo;
import org.dromara.ygpassport.domain.dto.WxResearchDto;
import org.dromara.ygpassport.domain.vo.ResearchVo;
import org.dromara.ygpassport.service.IResearchService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * 移动端-个人成长-科研经历
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/ygpassport/wxResearch")
public class WxResearchController extends BaseController {

    private final IResearchService researchService;

    /**
     * 查询科研经历列表
     *
     * @param jsonObject json中包含一个参数：stuNo（学号）
     *
     * @return R<List<WxResearchDto>>
     */
    @SaIgnore
    @PostMapping("/list")
    public R<List<WxResearchDto>> list(@RequestBody JSONObject jsonObject) {
        String stuNo = jsonObject.getStr("stuNo");

        List<ResearchVo> researchVoList = researchService.queryListByStuNo(stuNo);

        List<WxResearchDto> wxResearchDtoList = new ArrayList<>();

        for (ResearchVo researchVo : researchVoList) {
            WxResearchDto wxResearchDto = new WxResearchDto(researchVo);
            wxResearchDtoList.add(wxResearchDto);
        }
        return R.ok(wxResearchDtoList);
    }

    /**
     * 新增科研经历
     *
     * @param jsonObject json中包含一个参数：researchBo（科研经历bo）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/add")
    public R<Void> add(@RequestBody JSONObject jsonObject){
        ResearchBo bo = jsonObject.get("researchBo", ResearchBo.class);
        bo.setCreateTime(DateUtils.getNowDate());
        return toAjax(researchService.insertByBo(bo));
    }

    /**
     * 删除科研经历
     *
     * @param jsonObject json中包含一个参数：ids（需要删除的id数组）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/remove")
    public R<Void> remove(@RequestBody JSONObject jsonObject){
        Long[] ids = jsonObject.get("ids", Long[].class);
        return toAjax(researchService.deleteWithValidByIds(List.of(ids), true));
    }
}
