package org.dromara.ygpassport.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import cn.hutool.json.JSONObject;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.utils.DateUtils;
import org.dromara.common.web.core.BaseController;
import org.dromara.ygpassport.domain.bo.StudentLeaderExperienceBo;
import org.dromara.ygpassport.domain.dto.WxStudentLeaderExperienceDto;
import org.dromara.ygpassport.domain.vo.StudentLeaderExperienceVo;
import org.dromara.ygpassport.service.IStudentLeaderExperienceService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * 移动端-个人成长-学生干部经历
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/ygpassport/WxStudentLeaderExperience")
public class WxStudentLeaderExperienceController extends BaseController {

    private final IStudentLeaderExperienceService studentLeaderExperienceService;

    /**
     * 查询干部经历列表
     *
     * @param jsonObject json中包含一个参数：stuNo（学号）
     *
     * @return R<List<WxStudentLeaderExperienceDto>>
     */
    @SaIgnore
    @PostMapping("/list")
    public R<List<WxStudentLeaderExperienceDto>> list(@RequestBody JSONObject jsonObject){
        String stuNo = jsonObject.getStr("stuNo");

        List<StudentLeaderExperienceVo> studentLeaderExperienceVoList = studentLeaderExperienceService.queryListByStuNo(stuNo);

        List<WxStudentLeaderExperienceDto> wxStudentLeaderExperienceDtoList = new ArrayList<>();

        for (StudentLeaderExperienceVo studentLeaderExperienceVo : studentLeaderExperienceVoList) {
            WxStudentLeaderExperienceDto wxStudentLeaderExperienceDto = new WxStudentLeaderExperienceDto(studentLeaderExperienceVo);
            wxStudentLeaderExperienceDtoList.add(wxStudentLeaderExperienceDto);
        }

        return R.ok(wxStudentLeaderExperienceDtoList);
    }

    /**
     * 新增干部经历
     *
     * @param jsonObject json中包含一个参数：studentLeaderExperienceBo（干部经历bo）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/add")
    public R<Void> add(@RequestBody JSONObject jsonObject){
        StudentLeaderExperienceBo bo = jsonObject.get("studentLeaderExperienceBo", StudentLeaderExperienceBo.class);
        bo.setCreateTime(DateUtils.getNowDate());
        return toAjax(studentLeaderExperienceService.insertByBo(bo));
    }

    /**
     * 删除干部经历
     *
     * @param jsonObject json中包含一个参数：ids（需要删除的id数组）
     *
     * @return R<Void>
     */
    @SaIgnore
    @PostMapping("/remove")
    public R<Void> remove(@RequestBody JSONObject jsonObject){
        Long[] ids = jsonObject.get("ids", Long[].class);
        return toAjax(studentLeaderExperienceService.deleteWithValidByIds(List.of(ids), true));
    }
}
