package org.dromara.ygpassport.domain.bo;

import org.dromara.ygpassport.domain.ExactiveItems;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;
import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 第二课堂活动明细业务对象 ep_exactive_items
 *
 * @author Lion Li
 * @date 2024-04-24
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = ExactiveItems.class, reverseConvertGenerate = false)
public class ExactiveItemsBo extends BaseEntity {

    /**
     * 编号
     */
    @NotNull(message = "编号不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 学号
     */
    @NotBlank(message = "学号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuNo;

    /**
     * 级别id，在字典中配置
     */
    @NotNull(message = "级别id，在字典中配置不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long levelId;

    /**
     * 活动内容
     */
    @NotBlank(message = "活动内容不能为空", groups = { AddGroup.class, EditGroup.class })
    private String content;

    /**
     * 学分名称id，对应字典中配置的类别id
     */
    @NotNull(message = "学分名称id，对应字典中配置的类别id不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long activeTypeId;

    /**
     * 数量/分值
     */
    @NotNull(message = "数量/分值不能为空", groups = { AddGroup.class, EditGroup.class })
    private BigDecimal score;

    /**
     * 分值单位，如分学，在字典中配置
     */
    @NotNull(message = "分值单位，如分学，在字典中配置不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long scoreUnitId;

    /**
     * 活动时间
     */
    @NotNull(message = "活动时间不能为空", groups = { AddGroup.class, EditGroup.class })
    private Date activeDate;

    /**
     * 预留备注字段
     */
    private String remark;


}
