package org.dromara.ygpassport.domain.bo;

import org.dromara.ygpassport.domain.Scholarship;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;

/**
 * 奖学金获评记录业务对象 ep_scholarship
 *
 * @author Lion Li
 * @date 2024-01-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = Scholarship.class, reverseConvertGenerate = false)
public class ScholarshipBo extends BaseEntity {

    /**
     * 序号
     */
    @NotNull(message = "序号不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 学生学号
     */
    @NotBlank(message = "学生学号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuNo;

    /**
     * 奖项名称
     */
    @NotBlank(message = "奖项名称不能为空", groups = { AddGroup.class, EditGroup.class })
    private String scholarshipName;

    /**
     * 奖项内容
     */
    @NotBlank(message = "奖项内容不能为空", groups = { AddGroup.class, EditGroup.class })
    private String scholarshipDetail;

    /**
     * 等级
     */
    @NotNull(message = "等级不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long grade;

    /**
     * 学期
     */
    @NotNull(message = "学期不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long semester;

    /**
     * 附件信息存放路径
     */
//    @NotBlank(message = "附件信息存放路径不能为空", groups = { AddGroup.class, EditGroup.class })
    private String experienceFilePath;

    /**
     * 预留备注字段
     */
//    @NotBlank(message = "预留备注字段不能为空", groups = { AddGroup.class, EditGroup.class })
    private String remark;


}
