package org.dromara.ygpassport.domain.bo;

import org.dromara.ygpassport.domain.ScoreList;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;

import java.math.BigDecimal;

/**
 * 学生成绩信息列业务对象 ep_score_list
 *
 * @author Lion Li
 * @date 2023-10-30
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = ScoreList.class, reverseConvertGenerate = false)
public class ScoreListBo extends BaseEntity {

    /**
     * 编号
     */
    @NotNull(message = "编号不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 学生学号
     */
    @NotNull(message = "学生学号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuNo;

    /**
     * 专业
     */
    @NotNull(message = "专业不能为空", groups = { AddGroup.class, EditGroup.class })
    private Integer major;

    /**
     * 学期
     */
    @NotNull(message = "学期不能为空", groups = { AddGroup.class, EditGroup.class })
    private Integer semester;

    /**
     * 课程类型
     */
    @NotNull(message = "课程类型不能为空", groups = { AddGroup.class, EditGroup.class })
    private Integer courseType;

    /**
     * 课程代码
     */
    @NotNull(message = "课程代码不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long courseCode;

    /**
     * 课程名称
     */
    @NotBlank(message = "课程名称不能为空", groups = { AddGroup.class, EditGroup.class })
    private String courseName;

    /**
     * 学分值
     */
    @NotNull(message = "学分值不能为空", groups = { AddGroup.class, EditGroup.class })
    private BigDecimal hourCredit;

    /**
     * 分数值
     */
    @NotNull(message = "分数值不能为空", groups = { AddGroup.class, EditGroup.class })
    private BigDecimal score;

    /**
     * 绩点
     */
    @NotNull(message = "绩点不能为空", groups = { AddGroup.class, EditGroup.class })
    private Integer gradePoints;

    /**
     * 预留备注字段
     */
//    @NotBlank(message = "预留备注字段不能为空", groups = { AddGroup.class, EditGroup.class })
    private String remark;

    /**
     * 是否删除
     */
//    @NotNull(message = "是否删除不能为空", groups = { AddGroup.class, EditGroup.class })
    private Integer deleted;


}
