package org.dromara.ygpassport.domain.bo;

import org.dromara.ygpassport.domain.Student;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 学生详情业务对象 ep_student
 *
 * @author Lion Li
 * @date 2024-03-24
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = Student.class, reverseConvertGenerate = false)
public class StudentBo extends BaseEntity {

    /**
     * id
     */
    @NotNull(message = "id不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 学生学号
     */
    @NotBlank(message = "学生学号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuNo;

    /**
     * 学生姓名
     */
    @NotBlank(message = "学生姓名不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuName;

    /**
     * 学生年龄
     */
    @NotNull(message = "学生年龄不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long age;

    /**
     * 性别
     */
    @NotNull(message = "性别不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long stuSex;

    /**
     * 所属校区
     */
    @NotNull(message = "所属校区不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long stuCampus;

    /**
     * 所属学院
     */
    @NotNull(message = "所属学院不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long faculties;

    /**
     * 专业
     */
    @NotNull(message = "专业不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long stuMajor;

    /**
     * 年级
     */
    @NotBlank(message = "年级不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuGrade;

    /**
     * 班级名称
     */
    @NotBlank(message = "班级名称不能为空", groups = { AddGroup.class, EditGroup.class })
    private String stuClass;

    /**
     * 学制
     */
    @NotNull(message = "学制不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long academic;

    /**
     * 培养层次
     */
    @NotNull(message = "培养层次不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long stuLevels;

    /**
     * 照片路径
     */
//    @NotBlank(message = "照片路径不能为空", groups = { AddGroup.class, EditGroup.class })
    private String imagePath;

    /**
     * 姓名拼音
     */
    @NotBlank(message = "姓名拼音不能为空", groups = { AddGroup.class, EditGroup.class })
    private String pinyin;

    /**
     * 国籍
     */
    @NotBlank(message = "国籍不能为空", groups = { AddGroup.class, EditGroup.class })
    private String nationality;

    /**
     * 籍贯
     */
    @NotBlank(message = "籍贯不能为空", groups = { AddGroup.class, EditGroup.class })
    private String origin;

    /**
     * 民族
     */
    @NotBlank(message = "民族不能为空", groups = { AddGroup.class, EditGroup.class })
    private String ethnic;

    /**
     * 出生日期
     */
    @NotNull(message = "出生日期不能为空", groups = { AddGroup.class, EditGroup.class })
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date birthTime;

    /**
     * 手机号码
     */
    @NotBlank(message = "手机号码不能为空", groups = { AddGroup.class, EditGroup.class })
    private String phone;

    /**
     * 邮箱
     */
    @NotBlank(message = "邮箱不能为空", groups = { AddGroup.class, EditGroup.class })
    private String email;

    /**
     * 特长
     */
//    @NotBlank(message = "特长不能为空", groups = { AddGroup.class, EditGroup.class })
    private String specialty;

    /**
     * 地址
     */
    @NotBlank(message = "地址不能为空", groups = { AddGroup.class, EditGroup.class })
    private String address;

    /**
     * 导师
     */
//    @NotNull(message = "导师不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long mintorId;

    /**
     * 政治面貌
     */
//    @NotBlank(message = "政治面貌不能为空", groups = { AddGroup.class, EditGroup.class })
    private String policyStatus;
}
